Random Generators
=================

GeneratorProfileOrdinalUniform
------------------------------
.. autoclass:: poisson_approval.GeneratorProfileOrdinalUniform
    :members:

GeneratorProfileOrdinalVariations
---------------------------------
.. autoclass:: poisson_approval.GeneratorProfileOrdinalVariations
    :members:

GeneratorProfileHistogramUniform
--------------------------------
.. autoclass:: poisson_approval.GeneratorProfileHistogramUniform
    :members:

GeneratorProfileStrategyThreshold
---------------------------------
.. autoclass:: poisson_approval.GeneratorProfileStrategyThreshold
    :members:

GeneratorTauVectorUniform
-------------------------
.. autoclass:: poisson_approval.GeneratorTauVectorUniform
    :members:
